OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
4. Rīcības plāns
5. Pārskats
6. Statuss 37%

# statuss Commercial guarding, Leicester

## Vispārīga informācija

Izmantots rīks

  Commercial guarding, Leicester

sākts

  5 August 2017 by angela.baumeister@company.com

tika saglabāta

  7 June 2018 by hans.mittelmaier@company.com

## Atbildētie jautājumi katrā modulī

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Viss kārtībā
  - 3
  - 2 Uzmanību
  - 2 Atlikts jautājums
  - 2 Neatbildēts

  #### Augstas prioritātes riski

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Neatbildēts

  1

  1 Uzmanību

  1 Atlikts jautājums

  - 7 Neatbildēts
  - 1
  - 1 Uzmanību
  - 1 Atlikts jautājums

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More